
# Getting Started with MINDBODY Public API

## Install the Package

The package is compatible with Python versions `3.7+`.
Install the package from PyPi using the following pip command:

```bash
pip install mb-apimatic-sdk==1.0.0
```

You can also view the package at:
https://pypi.python.org/pypi/mb-apimatic-sdk/1.0.0

## Initialize the API Client

**_Note:_** Documentation for the client can be found [here.](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/client.md)

The following parameters are configurable for the API Client:

| Parameter | Type | Description |
|  --- | --- | --- |
| http_client_instance | `Union[Session, HttpClientProvider]` | The Http Client passed from the sdk user for making requests |
| override_http_client_configuration | `bool` | The value which determines to override properties of the passed Http Client from the sdk user |
| http_call_back | `HttpCallBack` | The callback value that is invoked before and after an HTTP call is made to an endpoint |
| timeout | `float` | The value to use for connection timeout. <br> **Default: 60** |
| max_retries | `int` | The number of times to retry an endpoint call if it fails. <br> **Default: 0** |
| backoff_factor | `float` | A backoff factor to apply between attempts after the second try. <br> **Default: 2** |
| retry_statuses | `Array of int` | The http statuses on which retry is to be done. <br> **Default: [408, 413, 429, 500, 502, 503, 504, 521, 522, 524]** |
| retry_methods | `Array of string` | The http methods on which retry is to be done. <br> **Default: ["GET", "PUT"]** |
| proxy_settings | [`ProxySettings`](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/proxy-settings.md) | Optional proxy configuration to route HTTP requests through a proxy server. |
| custom_header_authentication_credentials | [`CustomHeaderAuthenticationCredentials`](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/auth/custom-header-signature.md) | The credential object for Custom Header Signature |

The API client can be initialized as follows:

### Code-Based Client Initialization

```python
from mindbodypublicapi.configuration import Environment
from mindbodypublicapi.http.auth.custom_header_authentication import CustomHeaderAuthenticationCredentials
from mindbodypublicapi.mindbodypublicapi_client import MindbodypublicapiClient

client = MindbodypublicapiClient(
    custom_header_authentication_credentials=CustomHeaderAuthenticationCredentials(
        api_key='API-Key'
    ),
    environment=Environment.PRODUCTION
)
```

### Environment-Based Client Initialization

```python
from mindbodypublicapi.mindbodypublicapi_client import MindbodypublicapiClient

# Specify the path to your .env file if it’s located outside the project’s root directory.
client = MindbodypublicapiClient.from_environment(dotenv_path='/path/to/.env')
```

See the [Environment-Based Client Initialization](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/environment-based-client-initialization.md) section for details.

## Authorization

This API uses the following authentication schemes.

* [`API-Key (Custom Header Signature)`](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/auth/custom-header-signature.md)

## List of APIs

* [Appointment](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/appointment.md)
* [Class](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/class.md)
* [Client](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/client.md)
* [Cross Site](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/cross-site.md)
* [Enrollment](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/enrollment.md)
* [Payroll](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/payroll.md)
* [Pick a Spot](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/pick-a-spot.md)
* [Pricing Option](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/pricing-option.md)
* [Sale](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/sale.md)
* [Site](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/site.md)
* [Staff](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/staff.md)
* [User Token](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/controllers/user-token.md)

## SDK Infrastructure

### Configuration

* [ProxySettings](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/proxy-settings.md)
* [Environment-Based Client Initialization](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/environment-based-client-initialization.md)

### HTTP

* [HttpResponse](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/http-response.md)
* [HttpRequest](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/http-request.md)

### Utilities

* [ApiHelper](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/api-helper.md)
* [HttpDateTime](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/http-date-time.md)
* [RFC3339DateTime](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/rfc3339-date-time.md)
* [UnixDateTime](https://www.github.com/sdks-io/mb-apimatic-python-sdk/tree/1.0.0/doc/unix-date-time.md)

